@@ -156,10 +156,11 @@ class GitRepo(GitRepoBase):
         mapper = {
             "??": 128 if untracked_files == "all" else None,
             " D": 512,
+            "D ": 4,
             " M": 256,
             "A ": 1,
         }
-        result = {}
+        result: dict[str, int] = {}
         try:
             txt = self(["status", "--porcelain"])
         except subprocess.CalledProcessError as exc:
@@ -168,11 +169,18 @@ class GitRepo(GitRepoBase):
             if not line.strip():
                 continue
             tag, filename = line[:2], line[3:]
+            if tag not in mapper:
+                raise GitError(f"cannot map git status for '{tag}'")
             value = mapper[tag]
             if value:
-                result[filename] = value
+                result[filename] = (
+                    (result[filename] | value) if filename in result else value
+                )
         return result
 
+    def dirty(self) -> bool:
+        return bool(self.status(untracked_files="no"))
+
     def commit(
         self,
         paths: ListOfArgs,
